Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newcloudvm/UIWizardNewCloudVM.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newcloudvm/UIWizardNewCloudVM.cpp	(revision 84274)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newcloudvm/UIWizardNewCloudVM.cpp	(revision 84275)
@@ -163,5 +163,5 @@
         /* Check whether VM really added: */
         if (comMachine.isNotNull())
-            uiCommon().notifyCloudMachineRegistered(field("destination").toString(),
+            uiCommon().notifyCloudMachineRegistered(field("location").toString(),
                                                     field("profileName").toString(),
                                                     comMachine.GetId(),
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newcloudvm/UIWizardNewCloudVMPageBasic1.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newcloudvm/UIWizardNewCloudVMPageBasic1.cpp	(revision 84274)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newcloudvm/UIWizardNewCloudVMPageBasic1.cpp	(revision 84275)
@@ -45,7 +45,7 @@
 UIWizardNewCloudVMPage1::UIWizardNewCloudVMPage1()
     : m_fPolished(false)
-    , m_pDestinationLayout(0)
-    , m_pDestinationLabel(0)
-    , m_pDestinationComboBox(0)
+    , m_pLocationLayout(0)
+    , m_pLocationLabel(0)
+    , m_pLocationComboBox(0)
     , m_pCloudContainerLayout(0)
     , m_pAccountLabel(0)
@@ -58,10 +58,10 @@
 }
 
-void UIWizardNewCloudVMPage1::populateDestinations()
+void UIWizardNewCloudVMPage1::populateLocations()
 {
     /* To be executed just once, so combo should be empty: */
-    AssertReturnVoid(m_pDestinationComboBox->count() == 0);
-
-    /* Do we have OCI destination? */
+    AssertReturnVoid(m_pLocationComboBox->count() == 0);
+
+    /* Do we have OCI location? */
     bool fOCIPresent = false;
 
@@ -94,9 +94,9 @@
 
             /* Compose empty item, fill it's data: */
-            m_pDestinationComboBox->addItem(QString());
-            m_pDestinationComboBox->setItemData(m_pDestinationComboBox->count() - 1, comProvider.GetId(),        DestinationData_ID);
-            m_pDestinationComboBox->setItemData(m_pDestinationComboBox->count() - 1, comProvider.GetName(),      DestinationData_Name);
-            m_pDestinationComboBox->setItemData(m_pDestinationComboBox->count() - 1, comProvider.GetShortName(), DestinationData_ShortName);
-            if (m_pDestinationComboBox->itemData(m_pDestinationComboBox->count() - 1, DestinationData_ShortName).toString() == "OCI")
+            m_pLocationComboBox->addItem(QString());
+            m_pLocationComboBox->setItemData(m_pLocationComboBox->count() - 1, comProvider.GetId(),        LocationData_ID);
+            m_pLocationComboBox->setItemData(m_pLocationComboBox->count() - 1, comProvider.GetName(),      LocationData_Name);
+            m_pLocationComboBox->setItemData(m_pLocationComboBox->count() - 1, comProvider.GetShortName(), LocationData_ShortName);
+            if (m_pLocationComboBox->itemData(m_pLocationComboBox->count() - 1, LocationData_ShortName).toString() == "OCI")
                 fOCIPresent = true;
         }
@@ -106,5 +106,5 @@
     /* Set default: */
     if (fOCIPresent)
-        setDestination("OCI");
+        setLocation("OCI");
 }
 
@@ -125,5 +125,5 @@
 
     /* If provider chosen: */
-    if (!destinationId().isNull())
+    if (!locationId().isNull())
     {
         /* Main API request sequence, can be interrupted after any step: */
@@ -131,8 +131,8 @@
         {
             /* (Re)initialize Cloud Provider: */
-            m_comCloudProvider = m_comCloudProviderManager.GetProviderById(destinationId());
+            m_comCloudProvider = m_comCloudProviderManager.GetProviderById(locationId());
             if (!m_comCloudProviderManager.isOk())
             {
-                msgCenter().cannotFindCloudProvider(m_comCloudProviderManager, destinationId());
+                msgCenter().cannotFindCloudProvider(m_comCloudProviderManager, locationId());
                 break;
             }
@@ -405,12 +405,12 @@
 }
 
-void UIWizardNewCloudVMPage1::updateDestinationComboToolTip()
-{
-    const int iCurrentIndex = m_pDestinationComboBox->currentIndex();
+void UIWizardNewCloudVMPage1::updateLocationComboToolTip()
+{
+    const int iCurrentIndex = m_pLocationComboBox->currentIndex();
     if (iCurrentIndex != -1)
     {
-        const QString strCurrentToolTip = m_pDestinationComboBox->itemData(iCurrentIndex, Qt::ToolTipRole).toString();
+        const QString strCurrentToolTip = m_pLocationComboBox->itemData(iCurrentIndex, Qt::ToolTipRole).toString();
         AssertMsg(!strCurrentToolTip.isEmpty(), ("Data not found!"));
-        m_pDestinationComboBox->setToolTip(strCurrentToolTip);
+        m_pLocationComboBox->setToolTip(strCurrentToolTip);
     }
 }
@@ -448,21 +448,21 @@
 }
 
-void UIWizardNewCloudVMPage1::setDestination(const QString &strDestination)
-{
-    const int iIndex = m_pDestinationComboBox->findData(strDestination, DestinationData_ShortName);
+void UIWizardNewCloudVMPage1::setLocation(const QString &strLocation)
+{
+    const int iIndex = m_pLocationComboBox->findData(strLocation, LocationData_ShortName);
     AssertMsg(iIndex != -1, ("Data not found!"));
-    m_pDestinationComboBox->setCurrentIndex(iIndex);
-}
-
-QString UIWizardNewCloudVMPage1::destination() const
-{
-    const int iIndex = m_pDestinationComboBox->currentIndex();
-    return m_pDestinationComboBox->itemData(iIndex, DestinationData_ShortName).toString();
-}
-
-QUuid UIWizardNewCloudVMPage1::destinationId() const
-{
-    const int iIndex = m_pDestinationComboBox->currentIndex();
-    return m_pDestinationComboBox->itemData(iIndex, DestinationData_ID).toUuid();
+    m_pLocationComboBox->setCurrentIndex(iIndex);
+}
+
+QString UIWizardNewCloudVMPage1::location() const
+{
+    const int iIndex = m_pLocationComboBox->currentIndex();
+    return m_pLocationComboBox->itemData(iIndex, LocationData_ShortName).toString();
+}
+
+QUuid UIWizardNewCloudVMPage1::locationId() const
+{
+    const int iIndex = m_pLocationComboBox->currentIndex();
+    return m_pLocationComboBox->itemData(iIndex, LocationData_ID).toUuid();
 }
 
@@ -530,26 +530,26 @@
         }
 
-        /* Create destination layout: */
-        m_pDestinationLayout = new QGridLayout;
-        if (m_pDestinationLayout)
-        {
-            m_pDestinationLayout->setColumnStretch(0, 0);
-            m_pDestinationLayout->setColumnStretch(1, 1);
-
-            /* Create destination label: */
-            m_pDestinationLabel = new QLabel(this);
-            if (m_pDestinationLabel)
+        /* Create location layout: */
+        m_pLocationLayout = new QGridLayout;
+        if (m_pLocationLayout)
+        {
+            m_pLocationLayout->setColumnStretch(0, 0);
+            m_pLocationLayout->setColumnStretch(1, 1);
+
+            /* Create location label: */
+            m_pLocationLabel = new QLabel(this);
+            if (m_pLocationLabel)
             {
                 /* Add into layout: */
-                m_pDestinationLayout->addWidget(m_pDestinationLabel, 0, 0, Qt::AlignRight);
-            }
-            /* Create destination selector: */
-            m_pDestinationComboBox = new QIComboBox(this);
-            if (m_pDestinationComboBox)
-            {
-                m_pDestinationLabel->setBuddy(m_pDestinationComboBox);
+                m_pLocationLayout->addWidget(m_pLocationLabel, 0, 0, Qt::AlignRight);
+            }
+            /* Create location selector: */
+            m_pLocationComboBox = new QIComboBox(this);
+            if (m_pLocationComboBox)
+            {
+                m_pLocationLabel->setBuddy(m_pLocationComboBox);
 
                 /* Add into layout: */
-                m_pDestinationLayout->addWidget(m_pDestinationComboBox, 0, 1);
+                m_pLocationLayout->addWidget(m_pLocationComboBox, 0, 1);
             }
 
@@ -559,9 +559,9 @@
             {
                 /* Add into layout: */
-                m_pDestinationLayout->addWidget(m_pLabelDescription, 1, 0, 1, 2);
+                m_pLocationLayout->addWidget(m_pLabelDescription, 1, 0, 1, 2);
             }
 
             /* Add into layout: */
-            pMainLayout->addLayout(m_pDestinationLayout);
+            pMainLayout->addLayout(m_pLocationLayout);
         }
 
@@ -667,7 +667,7 @@
     if (gpManager)
         connect(gpManager, &UIVirtualBoxManager::sigCloudProfileManagerChange,
-                this, &UIWizardNewCloudVMPageBasic1::sltHandleDestinationChange);
-    connect(m_pDestinationComboBox, static_cast<void(QIComboBox::*)(int)>(&QIComboBox::activated),
-            this, &UIWizardNewCloudVMPageBasic1::sltHandleDestinationChange);
+                this, &UIWizardNewCloudVMPageBasic1::sltHandleLocationChange);
+    connect(m_pLocationComboBox, static_cast<void(QIComboBox::*)(int)>(&QIComboBox::activated),
+            this, &UIWizardNewCloudVMPageBasic1::sltHandleLocationChange);
     connect(m_pAccountComboBox, static_cast<void(QIComboBox::*)(int)>(&QIComboBox::currentIndexChanged),
             this, &UIWizardNewCloudVMPageBasic1::sltHandleAccountComboChange);
@@ -678,5 +678,5 @@
 
     /* Register fields: */
-    registerField("destination", this, "destination");
+    registerField("location", this, "location");
     registerField("profileName", this, "profileName");
 }
@@ -705,18 +705,18 @@
 {
     /* Translate page: */
-    setTitle(UIWizardNewCloudVM::tr("Destination to create"));
+    setTitle(UIWizardNewCloudVM::tr("Location to create"));
 
     /* Translate main label: */
-    m_pLabelMain->setText(UIWizardNewCloudVM::tr("Please choose the destination to create cloud virtual machine in.  This can "
+    m_pLabelMain->setText(UIWizardNewCloudVM::tr("Please choose the location to create cloud virtual machine in.  This can "
                                                  "be one of known cloud service providers below."));
 
-    /* Translate destination label: */
-    m_pDestinationLabel->setText(UIWizardNewCloudVM::tr("&Destination:"));
-    /* Translate received values of Destination combo-box.
+    /* Translate location label: */
+    m_pLocationLabel->setText(UIWizardNewCloudVM::tr("&Location:"));
+    /* Translate received values of Location combo-box.
      * We are enumerating starting from 0 for simplicity: */
-    for (int i = 0; i < m_pDestinationComboBox->count(); ++i)
-    {
-        m_pDestinationComboBox->setItemText(i, m_pDestinationComboBox->itemData(i, DestinationData_Name).toString());
-        m_pDestinationComboBox->setItemData(i, UIWizardNewCloudVM::tr("Create VM for cloud service provider."), Qt::ToolTipRole);
+    for (int i = 0; i < m_pLocationComboBox->count(); ++i)
+    {
+        m_pLocationComboBox->setItemText(i, m_pLocationComboBox->itemData(i, LocationData_Name).toString());
+        m_pLocationComboBox->setItemData(i, UIWizardNewCloudVM::tr("Create VM for cloud service provider."), Qt::ToolTipRole);
     }
 
@@ -733,5 +733,5 @@
     /* Adjust label widths: */
     QList<QWidget*> labels;
-    labels << m_pDestinationLabel;
+    labels << m_pLocationLabel;
     labels << m_pAccountLabel;
     labels << m_pAccountImageLabel;
@@ -739,9 +739,9 @@
     foreach (QWidget *pLabel, labels)
         iMaxWidth = qMax(iMaxWidth, pLabel->minimumSizeHint().width());
-    m_pDestinationLayout->setColumnMinimumWidth(0, iMaxWidth);
+    m_pLocationLayout->setColumnMinimumWidth(0, iMaxWidth);
     m_pCloudContainerLayout->setColumnMinimumWidth(0, iMaxWidth);
 
     /* Update tool-tips: */
-    updateDestinationComboToolTip();
+    updateLocationComboToolTip();
     updateAccountPropertyTableToolTips();
 }
@@ -752,8 +752,8 @@
     if (!m_fPolished)
     {
-        /* Populate destinations: */
-        populateDestinations();
+        /* Populate locations: */
+        populateLocations();
         /* Choose one of them, asynchronously: */
-        QMetaObject::invokeMethod(this, "sltHandleDestinationChange", Qt::QueuedConnection);
+        QMetaObject::invokeMethod(this, "sltHandleLocationChange", Qt::QueuedConnection);
         m_fPolished = true;
     }
@@ -791,8 +791,8 @@
 }
 
-void UIWizardNewCloudVMPageBasic1::sltHandleDestinationChange()
+void UIWizardNewCloudVMPageBasic1::sltHandleLocationChange()
 {
     /* Update tool-tip: */
-    updateDestinationComboToolTip();
+    updateLocationComboToolTip();
 
     /* Make image list focused by default: */
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newcloudvm/UIWizardNewCloudVMPageBasic1.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newcloudvm/UIWizardNewCloudVMPageBasic1.h	(revision 84274)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newcloudvm/UIWizardNewCloudVMPageBasic1.h	(revision 84275)
@@ -43,10 +43,10 @@
 class QIToolButton;
 
 /** Destination combo data fields. */
 enum
 {
-    DestinationData_ID              = Qt::UserRole + 1,
-    DestinationData_Name            = Qt::UserRole + 2,
-    DestinationData_ShortName       = Qt::UserRole + 3
+    LocationData_ID              = Qt::UserRole + 1,
+    LocationData_Name            = Qt::UserRole + 2,
+    LocationData_ShortName       = Qt::UserRole + 3
 };
 
@@ -65,6 +65,6 @@
     UIWizardNewCloudVMPage1();
 
-    /** Populates destinations. */
-    void populateDestinations();
+    /** Populates locations. */
+    void populateLocations();
     /** Populates accounts. */
     void populateAccounts();
@@ -76,6 +76,6 @@
     void populateFormProperties();
 
-    /** Updates destination combo tool-tips. */
-    void updateDestinationComboToolTip();
+    /** Updates location combo tool-tips. */
+    void updateLocationComboToolTip();
     /** Updates account property table tool-tips. */
     void updateAccountPropertyTableToolTips();
@@ -83,10 +83,10 @@
     void adjustAccountPropertyTable();
 
-    /** Defines @a strDestination. */
-    void setDestination(const QString &strDestination);
-    /** Returns destination. */
-    QString destination() const;
-    /** Returns destination ID. */
-    QUuid destinationId() const;
+    /** Defines @a strLocation. */
+    void setLocation(const QString &strLocation);
+    /** Returns location. */
+    QString location() const;
+    /** Returns location ID. */
+    QUuid locationId() const;
 
     /** Returns profile name. */
@@ -120,10 +120,10 @@
     CCloudProfile          m_comCloudProfile;
 
-    /** Holds the destination layout instance. */
-    QGridLayout *m_pDestinationLayout;
-    /** Holds the destination type label instance. */
-    QLabel      *m_pDestinationLabel;
-    /** Holds the destination type combo-box instance. */
-    QIComboBox  *m_pDestinationComboBox;
+    /** Holds the location layout instance. */
+    QGridLayout *m_pLocationLayout;
+    /** Holds the location type label instance. */
+    QLabel      *m_pLocationLabel;
+    /** Holds the location type combo-box instance. */
+    QIComboBox  *m_pLocationComboBox;
 
     /** Holds the cloud container layout instance. */
@@ -147,5 +147,5 @@
 {
     Q_OBJECT;
-    Q_PROPERTY(QString destination READ destination);
+    Q_PROPERTY(QString location READ location);
     Q_PROPERTY(QString profileName READ profileName);
 
@@ -177,6 +177,6 @@
 private slots:
 
-    /** Handles change in destination combo-box. */
-    void sltHandleDestinationChange();
+    /** Handles change in location combo-box. */
+    void sltHandleLocationChange();
 
     /** Handles change in account combo-box. */
@@ -43,10 +43,10 @@
 class QIToolButton;
 
-/** Destination combo data fields. */
+/** Location combo data fields. */
 enum
 {
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newcloudvm/UIWizardNewCloudVMPageExpert.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newcloudvm/UIWizardNewCloudVMPageExpert.cpp	(revision 84274)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newcloudvm/UIWizardNewCloudVMPageExpert.cpp	(revision 84275)
@@ -35,5 +35,5 @@
 UIWizardNewCloudVMPageExpert::UIWizardNewCloudVMPageExpert(bool fFullWizard)
     : UIWizardNewCloudVMPage2(fFullWizard)
-    , m_pCntDestination(0)
+    , m_pCntLocation(0)
     , m_pSettingsCnt(0)
 {
@@ -42,22 +42,22 @@
     if (pMainLayout)
     {
-        /* Create destination container: */
-        m_pCntDestination = new QGroupBox(this);
-        if (m_pCntDestination)
-        {
-            /* There is no destination table in short wizard form: */
+        /* Create location container: */
+        m_pCntLocation = new QGroupBox(this);
+        if (m_pCntLocation)
+        {
+            /* There is no location table in short wizard form: */
             if (!m_fFullWizard)
-                m_pCntDestination->setVisible(false);
-
-            /* Create destination layout: */
-            m_pDestinationLayout = new QGridLayout(m_pCntDestination);
-            if (m_pDestinationLayout)
+                m_pCntLocation->setVisible(false);
+
+            /* Create location layout: */
+            m_pLocationLayout = new QGridLayout(m_pCntLocation);
+            if (m_pLocationLayout)
             {
-                /* Create destination selector: */
-                m_pDestinationComboBox = new QIComboBox(m_pCntDestination);
-                if (m_pDestinationComboBox)
+                /* Create location selector: */
+                m_pLocationComboBox = new QIComboBox(m_pCntLocation);
+                if (m_pLocationComboBox)
                 {
                     /* Add into layout: */
-                    m_pDestinationLayout->addWidget(m_pDestinationComboBox, 0, 0);
+                    m_pLocationLayout->addWidget(m_pLocationComboBox, 0, 0);
                 }
 
@@ -77,5 +77,5 @@
 
                         /* Create account combo-box: */
-                        m_pAccountComboBox = new QIComboBox(m_pCntDestination);
+                        m_pAccountComboBox = new QIComboBox(m_pCntLocation);
                         if (m_pAccountComboBox)
                         {
@@ -84,5 +84,5 @@
                         }
                         /* Create account tool-button: */
-                        m_pAccountToolButton = new QIToolButton(m_pCntDestination);
+                        m_pAccountToolButton = new QIToolButton(m_pCntLocation);
                         if (m_pAccountToolButton)
                         {
@@ -99,5 +99,5 @@
 
                     /* Create profile property table: */
-                    m_pAccountPropertyTable = new QTableWidget(m_pCntDestination);
+                    m_pAccountPropertyTable = new QTableWidget(m_pCntLocation);
                     if (m_pAccountPropertyTable)
                     {
@@ -119,5 +119,5 @@
 
                     /* Create profile instances table: */
-                    m_pAccountImageList = new QListWidget(m_pCntDestination);
+                    m_pAccountImageList = new QListWidget(m_pCntLocation);
                     if (m_pAccountImageList)
                     {
@@ -136,10 +136,10 @@
 
                     /* Add into layout: */
-                    m_pDestinationLayout->addLayout(m_pCloudContainerLayout, 1, 0);
+                    m_pLocationLayout->addLayout(m_pCloudContainerLayout, 1, 0);
                 }
             }
 
             /* Add into layout: */
-            pMainLayout->addWidget(m_pCntDestination);
+            pMainLayout->addWidget(m_pCntLocation);
         }
 
@@ -176,7 +176,7 @@
     if (gpManager)
         connect(gpManager, &UIVirtualBoxManager::sigCloudProfileManagerChange,
-                this, &UIWizardNewCloudVMPageExpert::sltHandleDestinationChange);
-    connect(m_pDestinationComboBox, static_cast<void(QIComboBox::*)(int)>(&QIComboBox::activated),
-            this, &UIWizardNewCloudVMPageExpert::sltHandleDestinationChange);
+                this, &UIWizardNewCloudVMPageExpert::sltHandleLocationChange);
+    connect(m_pLocationComboBox, static_cast<void(QIComboBox::*)(int)>(&QIComboBox::activated),
+            this, &UIWizardNewCloudVMPageExpert::sltHandleLocationChange);
     connect(m_pAccountComboBox, static_cast<void(QIComboBox::*)(int)>(&QIComboBox::currentIndexChanged),
             this, &UIWizardNewCloudVMPageExpert::sltHandleAccountComboChange);
@@ -187,5 +187,5 @@
 
     /* Register fields: */
-    registerField("destination", this, "destination");
+    registerField("location", this, "location");
     registerField("profileName", this, "profileName");
 }
@@ -213,13 +213,13 @@
 void UIWizardNewCloudVMPageExpert::retranslateUi()
 {
-    /* Translate destination container: */
-    m_pCntDestination->setTitle(UIWizardNewCloudVM::tr("Destination"));
-
-    /* Translate received values of Destination combo-box.
+    /* Translate location container: */
+    m_pCntLocation->setTitle(UIWizardNewCloudVM::tr("Location"));
+
+    /* Translate received values of Location combo-box.
      * We are enumerating starting from 0 for simplicity: */
-    for (int i = 0; i < m_pDestinationComboBox->count(); ++i)
-    {
-        m_pDestinationComboBox->setItemText(i, m_pDestinationComboBox->itemData(i, DestinationData_Name).toString());
-        m_pDestinationComboBox->setItemData(i, UIWizardNewCloudVM::tr("Create VM for cloud service provider."), Qt::ToolTipRole);
+    for (int i = 0; i < m_pLocationComboBox->count(); ++i)
+    {
+        m_pLocationComboBox->setItemText(i, m_pLocationComboBox->itemData(i, LocationData_Name).toString());
+        m_pLocationComboBox->setItemData(i, UIWizardNewCloudVM::tr("Create VM for cloud service provider."), Qt::ToolTipRole);
     }
 
@@ -228,5 +228,5 @@
 
     /* Update tool-tips: */
-    updateDestinationComboToolTip();
+    updateLocationComboToolTip();
     updateAccountPropertyTableToolTips();
 }
@@ -239,8 +239,8 @@
         if (m_fFullWizard)
         {
-            /* Populate destinations: */
-            populateDestinations();
+            /* Populate locations: */
+            populateLocations();
             /* Choose one of them, asynchronously: */
-            QMetaObject::invokeMethod(this, "sltHandleDestinationChange", Qt::QueuedConnection);
+            QMetaObject::invokeMethod(this, "sltHandleLocationChange", Qt::QueuedConnection);
         }
         else
@@ -310,8 +310,8 @@
 }
 
-void UIWizardNewCloudVMPageExpert::sltHandleDestinationChange()
+void UIWizardNewCloudVMPageExpert::sltHandleLocationChange()
 {
     /* Update tool-tip: */
-    updateDestinationComboToolTip();
+    updateLocationComboToolTip();
 
     /* Make image list focused by default: */
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newcloudvm/UIWizardNewCloudVMPageExpert.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newcloudvm/UIWizardNewCloudVMPageExpert.h	(revision 84274)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/newcloudvm/UIWizardNewCloudVMPageExpert.h	(revision 84275)
@@ -35,5 +35,5 @@
 {
     Q_OBJECT;
-    Q_PROPERTY(QString destination READ destination);
+    Q_PROPERTY(QString location READ location);
     Q_PROPERTY(QString profileName READ profileName);
 
@@ -65,6 +65,6 @@
 private slots:
 
-    /** Handles change in destination combo-box. */
-    void sltHandleDestinationChange();
+    /** Handles change in location combo-box. */
+    void sltHandleLocationChange();
 
     /** Handles change in account combo-box. */
@@ -81,6 +81,6 @@
 private:
 
-    /** Holds the destination container instance. */
-    QGroupBox *m_pCntDestination;
+    /** Holds the location container instance. */
+    QGroupBox *m_pCntLocation;
     /** Holds the settings container instance. */
     QGroupBox *m_pSettingsCnt;
